==> nextcloud-22.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/es_NI.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Círculos",
    "Circles' files" : "Archivos de los círculos",
    "Select circles to filter by" : "Seleccionar los círculos a filtrar",
    "No circles found" : "No se encontraron círculos",
    "Please select circles to filter by" : "Por favor selecciona los círculos a filtrar",
    "No files found for the selected circles" : "No se encontraron archivos para los círculos seleccionados",
    "You created the circle {circle}" : "Creaste el círculo {circle}",
    "{author} created the circle {circle}" : "{author} creó el círculo {circle}",
    "You deleted {circle}" : "Borraste el círculo {circle}",
    "{author} deleted {circle}" : "{author} borró {circle}",
    "You linked {group} to {circle}" : "Vinculaste a {group} a {circle}",
    "{group} has been linked to {circle} by {author}" : "{author} vinculó {group} a {circle}",
    "You unlinked {group} from {circle}" : "Desvinculaste a {group} de {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{author} desvinculó {group} de {circle}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Cambiaste el nivel del grupo vinculado {group} en {circle} a %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} cambió el nivel del grupo vinculado {group} en {circle} a %1$s",
    "You sent a request to link {circle} with {remote}" : "Enviaste una solicitud para vincular {circle} con {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} envió una solicitud para vincular {circle} con {remote}",
    "{remote} requested a link with {circle}" : "{remote} solicitó una liga para {circle}",
    "The request to link {circle} with {remote} has been rejected" : "La solicitud para vincular{circle} con {remote} fue rechazada",
    "The request to link {remote} with {circle} has been canceled remotely" : "La solicitud para vincular {remote} con {circle} ha sido cancelada remotamente",
    "The request to link {circle} with {remote} has been accepted" : "La solicitud para vincular {circle} con {rempte} ha sido aceptada",
    "You dismissed the request to link {remote} with {circle}" : "Descartaste la solicitud para vincular {remote} con {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} descartó la solicitud para vincular {remote} con {circle}",
    "You canceled the request to link {circle} with {remote}" : "Cancelaste la solicitud para vincular {circle} con {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} canceló la solicitud para vincular {circle} con {remote}",
    "You accepted the request to link {remote} with {circle}" : "Aceptaste la solicitud para vincular {remote} con {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} aceptó la solicitud para vincular {remote} con {circle}",
    "A link between {circle} and {remote} is now up and running" : "La liga entre {circle} y {remote} está ahora lista y funcionando",
    "The link between {circle} and {remote} has been shutdown remotely" : "La liga entre {circle} y {remote} ha sido deshabilitada remotamente",
    "You closed the link between {circle} and {remote}" : "Cerraste la liga entre {cirlce} y {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} cerró la liga entre {circle} y {remote}",
    "You joined {circle}" : "Te uniste a {circle}",
    "{member} joined {circle}" : "{member} se unió a {circle}",
    "You accepted the invitation to join {circle}" : "Aceptaste la invitación para unirte a {cirlce}",
    "{member} accepted the invitation to join {circle}" : "{member} aceptó la inivtación para unirse a {circle}",
    "You added {member} as member to {circle}" : "Agregaste a {member} como miembro de {circle}",
    "You have been added as member to {circle} by {author}" : "Has sido agregado como miembro de {circle} por {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} ha sido agregado como un miembro de {circle} por {author}",
    "You added {external} to {circle}" : "Agregaste a {external} a {circle}",
    "{external} has been added to {circle} by {author}" : "{external} ha sido agregado a {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Aceptaste la solicitud de {member} para unirse a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Tu solicitud para unirte a {circle} ha sido aceptada por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La solicitud de {member} para unirse  a {circle} ha sido aceptada por {author}",
    "You left {circle}" : "Dejaste el {circle}",
    "{member} left {circle}" : "{member} dejó {circle}",
    "You declined the invitation to join {circle}" : "Declinaste la invitacion a unirte a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} declinó la invitación para unirse a {cricle}",
    "You cancelled your request to join {circle}" : "Cancelaste tu solicitud para unirte a {cricle}",
    "{member} cancelled his request to join {circle}" : "{member} canceló su solicitud para unirse a {circle}",
    "You removed {member} from {circle}" : "Eliminaste a {member} de {circle}",
    "You have been removed from {circle} by {author}" : "Has sido eliminado de {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{member} ha sido eliminado de {circle} por {author}",
    "You removed {external} from {circle}" : "Eliminaste a {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} ha sido eliminado de {circle} por {autor}",
    "You cancelled {member}'s invitation to join {circle}" : "Cancelaste la invitación de {member} para unirse a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Tu invitación para unirte a {circle} ha sido cancelada por {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} canceló la invitación de {member} para unirse a {crcle}",
    "You dismissed {member}'s request to join {circle}" : "Descartaste la solicitud de {member} para unirse a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Tu solicitud para unirte a {circle} fue descartada por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La solicitud de {member} para unirse a {circle} ha sido descartada por {author}",
    "You invited {member} to join {circle}" : "Invitaste a {member} a unirse a {circle}",
    "You have been invited to join {circle} by {author}" : "{author} te ha invitado a unirte a {circle}",
    "{member} has been invited to join {circle} by {author}" : "{member} fue invitado a unirse a {circle} por {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Cambiaste el nivel de {member} en el círculo a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} cambió tu nivel en {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} cambió el nivel de {member} en {circle}  a %1$s",
    "You sent a request to join {circle}" : "Enviaste una solicitud para unirte a {circle}",
    "{member} sent a request to join {circle}" : "{member} envió una solicitud para unirse a {circle}",
    "You are the new owner of {circle}" : "Eres el nuevo dueño de {circle}",
    "{member} is the new owner of {circle}" : "{member} es el nuevo dueño de {circle}",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Cualquier evento importante en un <strong>Círculo</strong> que estés moderando",
    "Shared to Circles" : "Compartido a Círculos",
    "Personal" : "Personal",
    "Contact" : "Contacto",
    "Circle" : "Círculo",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Dueño",
    "%s shared »%s« with you." : "%s compartió »%s« contigo.",
    "%s on %s" : "%s en %s",
    "Password to access »%s«" : "Contraseña para acceder  »%s«",
    "Click the button below to open it." : "Haz click en el botón para abrirlo.",
    "Open »%s«" : "Abrir »%s«",
    "Circle not found" : "Círculo no encontrado",
    "A circle with that name exists" : "Un círculo con ese nombre ya existe",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "No puedes usar la Aplicación de Círculos hasta que tu adminsitrador haya permitido al menos un tipo de círculo",
    "This member does not exist" : "Este miembro no existe",
    "This user is already a member of the circle" : "El usuario ya es un miembro del círculo",
    "Federated link not found" : "No se encontró la liga",
    "This feature is not available for personal circles" : "Esta característica no está disponible para círculos personales",
    "The circle is not federated" : "El círculo no es federado",
    "You cannot join this circle" : "No puedes unirte a este cículo",
    "This member is not a moderator" : "Este miembro no es un moderador",
    "Insufficient privileges" : "Privilegios insuficientes",
    "This member is the owner of the circle" : "Este miembro es el dueño del círculo",
    "Level cannot be changed for this type of member" : "El nivel no puede ser cambiado para este tipo de miembro",
    "You are already a member of this circle" : "Ya eres un miembro de este círculo",
    "You have been blocked from this circle" : "Has sido bloqueado de este círculo",
    "The user is already a member of this circle" : "El usuario ya es un miembro de este círculo",
    "The user has already been invited into this circle" : "El usuario ya ha sido invitado a este círculo",
    "Accept" : "Aceptar",
    "You need a specify a type of circle" : "Necesitas especificar un tipo de círculo",
    "This member is not the owner of the circle" : "Este miembro no es el dueño del círculo",
    "This member is not an admin of the circle" : "Este miembro no es un administador del círculo",
    "This group does not exist" : "Este grupo no existe",
    "This group is already linked to the circle" : "Este grupo ya ha sido ligado a este círculo",
    "You cannot edit level in a personal circle" : "No puedes editar el nivel en un círculo personal",
    "Group cannot be set as owner of a circle" : "Un Grupo no puede ser establecido como dueño de un círculo",
    "This user does not exist" : "Este usuario no existe",
    "Email format is not valid" : "El formato de la dirección de correo electrónico no es válido",
    "This contact is not available" : "Este contacto no está disponible",
    "Could not find share" : "No se encontró el elemento compartido",
    "No files in here" : "No hay archivos aquí",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Groups can be linked to circles." : "Los grupos se pueden vincular a círculos",
    "Are you sure you want to transfer your ownership?" : "¿Estás seguro que quieres transferir tu propiedad?",
    "This action is irreversible" : "Esta acción es irreversible",
    "Personal circle" : "Círculo personal",
    "Secret circle" : "Círculo secreto",
    "Closed circle" : "Círculo cerrado",
    "Public circle" : "Círculo público",
    "Link Removed" : "Liga eliminada",
    "Link down" : "Liga no disponible",
    "Setting link" : "Estableciendo liga",
    "Request dismissed" : "Solicitud descartada",
    "Request sent" : "Solicitud enviada",
    "Link requested" : "Liga solicitada",
    "Link up" : "Liga disponible",
    "Personal Circle" : "Círculo Personal",
    "Secret Circle" : "Círculo Secreto",
    "Closed Circle" : "Círculo Cerrado",
    "Public Circle" : "Círculo Público",
    "Secret" : "Secreto",
    "Closed" : "Cerrado",
    "Public" : "Público",
    "Not a member" : "No es un miembro",
    "Unknown" : "Desconocido",
    "Invited" : "Invitado",
    "Requesting" : "Solicitando",
    "Blocked" : "Bloqueado",
    "Kicked" : "Expulsado",
    "This operation will add/invite all members of the group to the circle" : "Esta operación agregará/invitará a todos los miembros del grupo al círculo",
    "Please confirm" : "Por favor confirma",
    "Are you sure you want to leave this circle?" : "¿Estás seguro que quieres dejar este círculo?",
    "Are you sure you want to delete this circle?" : "¿Estás seguro que deseas borrar este círculo?",
    "Mail Address" : "Dirección de correo",
    "Kick this member" : "Sacar a este miembro",
    "Accept the request" : "Aceptar la solicitud",
    "Dismiss the request" : "Descartar la solicitud",
    "Unlink this group" : "Desligar este grupo",
    "Remove this link" : "Eliminar esta liga",
    "Cancel the link request" : "Cancelar la solicitud de liga",
    "Accept the link request" : "Aceptar la solicitud de liga",
    "Reject the link request" : "Rechazar la solicitud de liga",
    "Cannot join this circle" : "No se puedes unirte a este círculo",
    "no error message" : "no hay mensaje de error",
    "You have joined this circle" : "Te has unido a este círculo",
    "You have requested to join this circle" : "Has solicitado unirte a este círculo",
    "You have left this circle" : "Has dejado este círculo",
    "Cannot leave this circle" : "No puedes dejar este círculo",
    "You have deleted this circle" : "Has borrado este círculo",
    "Cannot delete this circle" : "No es posible borrar este círculo ",
    " {type} '{name}' created" : " {type} '{name}' ha sido creado",
    " {type} '{name}' could not be created" : " {type} '{name}' no pudo ser creado",
    "Issue while retrieving the details of this circle" : "Se presentó un tema al recuperar los detalles de este círculo",
    "Issue while retrieving the list of circles" : "Se presentó un tema al recuperar la lista de círculos",
    "Group '{name}' successfully added to the circle" : "El grupo '{name}' fue agregado al círculo exitosamente",
    "Group '{name}' could not be added to the circle" : "El grupo '{name}' no pudo ser agregado al círculo",
    "Group '{name}' updated" : "El grupo '{name}' fue actualizado",
    "Group '{name}' could not be updated" : "El grupo '{name}' no pudo ser actualizado",
    "Group '{name}' successfully removed from the circle" : "El grupo '{name}' fue eliminado exitosamente del círculo",
    "Group '{name}' could not be removed from the circle" : "El grupo '{name}' no pudo ser eliminado del círculo",
    "A link to <b>{remote}</b> could not be initiated" : "No fue posible inicializar la liga a <b>{remote}</b>",
    "A link to <b>{remote}</b> has been requested." : "Se ha solicitado una liga a <b>{remote}</b>.",
    "the link to <b>{remote}</b> is now up and running." : "la liga a <b>{remote}</b> ya está disponible y funcionando.",
    "The status of the link could not be updated" : "El estatus de la liga no pudo ser actualizado",
    "The status of the link has been updated" : "El estatus de la liga ha sido actualizado",
    "Local User" : "Usuario local",
    "Local Group" : "Grupo local",
    "The email address '{email}' was added to the circle" : "La dirección de correo '{email}' fue agregada al círculo",
    "The email address '{email}' could not be added to the circle" : "La dirección de correo electrónico '{email}' no pudo ser agregara al círculo",
    "Members of the group '{name}' were added to the circle" : "Miembros del grupo '{name}' fueron agregados al círculo",
    "Members of the group '{name}' could not be added to the circle" : "Miembros del grupo '{name}' no pudieron ser agregados al círculo",
    "Members of the group '{name}' were invited to the circle" : "Miembros del grupo '{name}' fueron invitados al círculo",
    "Members of the group '{name}' could not be invited to the circle" : "Miembros del grupo '{name}' no pudieron ser inivitados al círculo",
    "Issue while saving settings" : "Se presentó un tema al guardar las configuraciones",
    "Settings saved." : "Configuraciones guardadas.",
    "%s shared »%s« with '%s'." : "%s compartió »%s« con '%s'.",
    "The name of your circle must contain at least 3 characters" : "El nombre de tu círculo debe contener al menos 3 caracteres",
    "Linked Groups are not allowed on this Nextcloud" : "No se permiten Grupos Ligados en este Nextcloud",
    "Federated circles are not allowed on this Nextcloud" : "No se permiten los círculos federados en este Nextcloud",
    "Sharing Frame does not exist" : "No existe el Marco para Compartir. ",
    "You cannot create this type of circle" : "No puede crear un círculo de este tipo",
    "You cannot display this type of circle" : "No puedes desplegar un círculo de este tipo",
    "Federated link does not have a valid format" : "La liga federada no tiene un formato válido",
    "Federated circles are not allowed on the remote Nextcloud" : "No se permiten los círculos federados en el Nextcloud remoto",
    "Remote circle does not accept federated links" : "El círculo remoto no acepta ligas federadas",
    "Trying to link a circle to itself" : "Intentando vincular círculo a si mismo",
    "This link exists already" : "Esta liga ya existe",
    "The requested remote circle does not exist" : "El círculo remoto solicitado no existe",
    "The remote host is down or the Circles app is not installed on it" : "El servidor remoto está abajo o bien la aplicación de Círculos no está instalada en él",
    "Cannot proceed with this status update" : "No es posible proceder con esta actualización de estatus",
    "Create a new circle" : "Crear un nuevo círculo",
    "Select a circle type" : "Seleccionar un tipo de círculo",
    "Create a personal circle" : "Crear un círculo personal",
    "Create a public circle" : "Crear un círculo público",
    "Create a closed circle" : "Crear un círculo cerrado",
    "Create a secret circle" : "Crear un círculo secreto",
    "Creation" : "Creación",
    "A personal circle is a list of users known only to the owner." : "Un círculo personal es una lista de usuarios que es conocida solo por el dueño. ",
    "This is the right option if you want to do recurrent sharing with the same list of local users." : "Esta es la opción más indicada si quieres compartir recurrentemente con la misma lista de usuarios locales. ",
    "A secret circle is an hidden group that can only be seen by its members or by people knowing the exact name of the circle." : "Un círculo secreto es un grupo oculto que solo puede ser visto por sus miembros o por personas que conozcan el nombre exacto del círculo.",
    "Non-members won't be able to find your secret circle using the search bar." : "Sólo los miembros podrán encontrar tu círculo secreto usando la barra de búsqueda.",
    "Joining a closed circle requires an invitation or confirmation by a moderator." : "Unirse a un círculo cerrado requiere de una invitación o una confirmación de un moderador.",
    "A public circle is an open group visible to anyone willing to join." : "Un círculo público es un grupo abierto, visible a todos aquellos que quieran unirse.",
    "Anyone can see, join, and access the items shared within the circle." : "Todos pueden ver, unirse y accesar a los elementos compartidos dentro del círculo. ",
    "Personal circles" : "Círculos personales",
    "Public circles" : "Círculos públicos",
    "Closed circles" : "Círculos cerrados",
    "Secret circles" : "Círculos secretos",
    "All circles" : "Todos los círculos",
    "Search circles" : "Buscar círculos",
    "No filter" : "Sin filtro",
    "Circles you belong to" : "Círculos a los que perteneces",
    "Circles you own" : "Círculos que te pertenecen ",
    "No circle selected" : "No se ha selecccionado un círculo",
    "Settings" : "Configuraciones ",
    "Pending invitation to join this circle" : "Invitación pendiente para unirte a este círculo",
    "You have a pending request to join this circle" : "Tienes una solicitud pendiente para unirte a este círculo ",
    "Add a member" : "Agegar un miembro",
    "Link a group" : "Ligar un grupo",
    "Link a circle" : "Ligar un círculo",
    "Join this circle" : "Únete a este círculo",
    "Delete circle" : "Borrar círculo",
    "Edit circle" : "Editar círculo",
    "Accept the invitation" : "Aceptar la invitación",
    "Decline the invitation" : "Declinar la invitación",
    "Leave this circle" : "Dejar este círculo",
    "Link to a circle" : "Ligar a un círculo",
    "Return to menu" : "Regresar al menú",
    "Username" : "Usuario",
    "Level" : "Nivel",
    "Status" : "Estatus",
    "Joined" : "Se ha unido",
    "Group Name" : "Nombre del Grupo",
    "Link" : "Ligas",
    "Linked" : "Ligado",
    "Description" : "Descripción",
    "Change password" : "Cambiar contraseña",
    "Allow Federated Links" : "Permitir Ligas Federadas",
    "Makes the circle federated, and enables sharing between federated circles" : "Hace al círculo federado y habilita el compartir entre círculos federados",
    "Accept Link Request Automatically" : "Aceptar las Solicitudes de Ligas Automáticamente",
    "Warning: Enabling this will automatically accept new link requests from other circles." : "Advertencia: Habilitar esta opción aceptará automáticamente las nuevas solicitudes de ligas de otros círculos. ",
    "Save settings" : "Guardar configuraciones"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/es_NI.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Círculos",
    "Circles' files" : "Archivos de los círculos",
    "Select circles to filter by" : "Seleccionar los círculos a filtrar",
    "No circles found" : "No se encontraron círculos",
    "Please select circles to filter by" : "Por favor selecciona los círculos a filtrar",
    "No files found for the selected circles" : "No se encontraron archivos para los círculos seleccionados",
    "You created the circle {circle}" : "Creaste el círculo {circle}",
    "{author} created the circle {circle}" : "{author} creó el círculo {circle}",
    "You deleted {circle}" : "Borraste el círculo {circle}",
    "{author} deleted {circle}" : "{author} borró {circle}",
    "You linked {group} to {circle}" : "Vinculaste a {group} a {circle}",
    "{group} has been linked to {circle} by {author}" : "{author} vinculó {group} a {circle}",
    "You unlinked {group} from {circle}" : "Desvinculaste a {group} de {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{author} desvinculó {group} de {circle}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Cambiaste el nivel del grupo vinculado {group} en {circle} a %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} cambió el nivel del grupo vinculado {group} en {circle} a %1$s",
    "You sent a request to link {circle} with {remote}" : "Enviaste una solicitud para vincular {circle} con {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} envió una solicitud para vincular {circle} con {remote}",
    "{remote} requested a link with {circle}" : "{remote} solicitó una liga para {circle}",
    "The request to link {circle} with {remote} has been rejected" : "La solicitud para vincular{circle} con {remote} fue rechazada",
    "The request to link {remote} with {circle} has been canceled remotely" : "La solicitud para vincular {remote} con {circle} ha sido cancelada remotamente",
    "The request to link {circle} with {remote} has been accepted" : "La solicitud para vincular {circle} con {rempte} ha sido aceptada",
    "You dismissed the request to link {remote} with {circle}" : "Descartaste la solicitud para vincular {remote} con {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} descartó la solicitud para vincular {remote} con {circle}",
    "You canceled the request to link {circle} with {remote}" : "Cancelaste la solicitud para vincular {circle} con {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} canceló la solicitud para vincular {circle} con {remote}",
    "You accepted the request to link {remote} with {circle}" : "Aceptaste la solicitud para vincular {remote} con {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} aceptó la solicitud para vincular {remote} con {circle}",
    "A link between {circle} and {remote} is now up and running" : "La liga entre {circle} y {remote} está ahora lista y funcionando",
    "The link between {circle} and {remote} has been shutdown remotely" : "La liga entre {circle} y {remote} ha sido deshabilitada remotamente",
    "You closed the link between {circle} and {remote}" : "Cerraste la liga entre {cirlce} y {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} cerró la liga entre {circle} y {remote}",
    "You joined {circle}" : "Te uniste a {circle}",
    "{member} joined {circle}" : "{member} se unió a {circle}",
    "You accepted the invitation to join {circle}" : "Aceptaste la invitación para unirte a {cirlce}",
    "{member} accepted the invitation to join {circle}" : "{member} aceptó la inivtación para unirse a {circle}",
    "You added {member} as member to {circle}" : "Agregaste a {member} como miembro de {circle}",
    "You have been added as member to {circle} by {author}" : "Has sido agregado como miembro de {circle} por {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} ha sido agregado como un miembro de {circle} por {author}",
    "You added {external} to {circle}" : "Agregaste a {external} a {circle}",
    "{external} has been added to {circle} by {author}" : "{external} ha sido agregado a {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Aceptaste la solicitud de {member} para unirse a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Tu solicitud para unirte a {circle} ha sido aceptada por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La solicitud de {member} para unirse  a {circle} ha sido aceptada por {author}",
    "You left {circle}" : "Dejaste el {circle}",
    "{member} left {circle}" : "{member} dejó {circle}",
    "You declined the invitation to join {circle}" : "Declinaste la invitacion a unirte a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} declinó la invitación para unirse a {cricle}",
    "You cancelled your request to join {circle}" : "Cancelaste tu solicitud para unirte a {cricle}",
    "{member} cancelled his request to join {circle}" : "{member} canceló su solicitud para unirse a {circle}",
    "You removed {member} from {circle}" : "Eliminaste a {member} de {circle}",
    "You have been removed from {circle} by {author}" : "Has sido eliminado de {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{member} ha sido eliminado de {circle} por {author}",
    "You removed {external} from {circle}" : "Eliminaste a {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} ha sido eliminado de {circle} por {autor}",
    "You cancelled {member}'s invitation to join {circle}" : "Cancelaste la invitación de {member} para unirse a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Tu invitación para unirte a {circle} ha sido cancelada por {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} canceló la invitación de {member} para unirse a {crcle}",
    "You dismissed {member}'s request to join {circle}" : "Descartaste la solicitud de {member} para unirse a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Tu solicitud para unirte a {circle} fue descartada por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La solicitud de {member} para unirse a {circle} ha sido descartada por {author}",
    "You invited {member} to join {circle}" : "Invitaste a {member} a unirse a {circle}",
    "You have been invited to join {circle} by {author}" : "{author} te ha invitado a unirte a {circle}",
    "{member} has been invited to join {circle} by {author}" : "{member} fue invitado a unirse a {circle} por {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Cambiaste el nivel de {member} en el círculo a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} cambió tu nivel en {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} cambió el nivel de {member} en {circle}  a %1$s",
    "You sent a request to join {circle}" : "Enviaste una solicitud para unirte a {circle}",
    "{member} sent a request to join {circle}" : "{member} envió una solicitud para unirse a {circle}",
    "You are the new owner of {circle}" : "Eres el nuevo dueño de {circle}",
    "{member} is the new owner of {circle}" : "{member} es el nuevo dueño de {circle}",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Cualquier evento importante en un <strong>Círculo</strong> que estés moderando",
    "Shared to Circles" : "Compartido a Círculos",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Hidden" : "Oculto",
    "Local" : "Local",
    "Root" : "Raíz",
    "Federated" : "Federado",
    "Contact" : "Contacto",
    "Circle" : "Círculo",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Dueño",
    "%s shared »%s« with you." : "%s compartió »%s« contigo.",
    "%s on %s" : "%s en %s",
    "Password to access »%s«" : "Contraseña para acceder  »%s«",
    "Click the button below to open it." : "Haz click en el botón para abrirlo.",
    "Open »%s«" : "Abrir »%s«",
    "Circle not found" : "Círculo no encontrado",
    "This member does not exist" : "Este miembro no existe",
    "Federated link not found" : "No se encontró la liga",
    "This feature is not available for personal circles" : "Esta característica no está disponible para círculos personales",
    "The circle is not federated" : "El círculo no es federado",
    "You cannot join this circle" : "No puedes unirte a este cículo",
    "This member is not a moderator" : "Este miembro no es un moderador",
    "Insufficient privileges" : "Privilegios insuficientes",
    "This member is the owner of the circle" : "Este miembro es el dueño del círculo",
    "Level cannot be changed for this type of member" : "El nivel no puede ser cambiado para este tipo de miembro",
    "You are already a member of this circle" : "Ya eres un miembro de este círculo",
    "You have been blocked from this circle" : "Has sido bloqueado de este círculo",
    "Accept" : "Aceptar",
    "%s" : "%s",
    "Personal Circle" : "Círculo Personal",
    "You need a specify a type of circle" : "Necesitas especificar un tipo de círculo",
    "A circle with that name exists" : "Un círculo con ese nombre ya existe",
    "This member is not the owner of the circle" : "Este miembro no es el dueño del círculo",
    "This member is not an admin of the circle" : "Este miembro no es un administador del círculo",
    "This group does not exist" : "Este grupo no existe",
    "This group is already linked to the circle" : "Este grupo ya ha sido ligado a este círculo",
    "You cannot edit level in a personal circle" : "No puedes editar el nivel en un círculo personal",
    "Group cannot be set as owner of a circle" : "Un Grupo no puede ser establecido como dueño de un círculo",
    "Email format is not valid" : "El formato de la dirección de correo electrónico no es válido",
    "This contact is not available" : "Este contacto no está disponible",
    "No files in here" : "No hay archivos aquí",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
